---
title: <span class="badge object-type-scalar"></span> RequestsPerSecond
---
# <span class="badge object-type-scalar"></span> RequestsPerSecond

Throughput: requests/sec (rps)

## Definition

```python
# Throughput: requests/sec (rps)
RequestsPerSecond: typing.Literal["reqps"] = "reqps"
```
